@@ -1,3 +1,4 @@
+import datetime
 from flask_appbuilder._compat import as_unicode
 
 def dict_to_json(xcol, ycols, labels, value_columns):
@@ -15,6 +16,7 @@ def dict_to_json(xcol, ycols, labels, value_columns):
             A list of dicts with the values to convert
     """
     json_data = dict()
+
     json_data['cols'] = [{'id': xcol,
                           'label': as_unicode(labels[xcol]),
                           'type': 'string'}]
@@ -25,8 +27,11 @@ def dict_to_json(xcol, ycols, labels, value_columns):
     json_data['rows'] = []
     for value in value_columns:
         row = {'c': []}
-        for ycol in ycols:
+        if isinstance(value[xcol], datetime.date):
+            row['c'].append({'v': (str(value[xcol]))})
+        else:
             row['c'].append({'v': (value[xcol])})
+        for ycol in ycols:
             if value[ycol]:
                 row['c'].append({'v': int(value[ycol])})
             else:
