@@ -13,7 +13,7 @@ from group import GroupByDateYear, GroupByDateMonth, GroupByCol
 
 from mixins import FileColumn, ImageColumn
 from ..filemanager import FileManager, ImageManager
-
+from .._compat import as_unicode
 log = logging.getLogger(__name__)
 
 
@@ -160,14 +160,14 @@ class SQLAModel(DataModel):
             return query.all()
     """
 
-    def query_simple_group(self, group_by='', filters=None):
+    def query_simple_group(self, group_by='', aggregate_func = None, aggregate_col = None, filters=None):
         query = self.session.query(self.obj)
         query = self._get_base_query(query=query, filters=filters)
         query_result = query.all()
         group = GroupByCol(group_by, 'Group by')
         return group.apply(query_result)
 
-
+    # still not in use
     def query_group(self, group_bys, filters=None):
         query = self.session.query(self.obj)
         query = self._get_base_query(query=query, filters=filters)
@@ -242,6 +242,13 @@ class SQLAModel(DataModel):
     def is_relation_many_to_many(self, prop):
         return prop.direction.name == 'MANYTOMANY'
 
+    def is_relation_one_to_one(self, prop):
+        return prop.direction.name == 'ONETOONE'
+
+    def is_relation_one_to_many(self, prop):
+        return prop.direction.name == 'ONETOMANY'
+
+
     def is_pk(self, col):
         return col.primary_key
 
@@ -258,16 +265,16 @@ class SQLAModel(DataModel):
         try:
             self.session.add(item)
             self.session.commit()
-            flash(unicode(self.add_row_message), 'success')
+            flash(as_unicode(self.add_row_message), 'success')
             return True
         except IntegrityError as e:
-            flash(unicode(self.add_integrity_error_message), 'warning')
-            log.warning("Add record integrity error")
+            flash(as_unicode(self.add_integrity_error_message), 'warning')
+            log.warning("Add record integrity error: {0}".format(str(e)))
             self.session.rollback()
             return False
-        except:
-            flash(unicode(self.general_error_message + ' ' + str(sys.exc_info()[0])), 'danger')
-            log.exception("Add record error")
+        except Exception as e:
+            flash(as_unicode(self.general_error_message + ' ' + str(sys.exc_info()[0])), 'danger')
+            log.exception("Add record error: {0}".format(str(e)))
             self.session.rollback()
             return False
 
@@ -275,16 +282,16 @@ class SQLAModel(DataModel):
         try:
             self.session.merge(item)
             self.session.commit()
-            flash(unicode(self.edit_row_message), 'success')
+            flash(as_unicode(self.edit_row_message), 'success')
             return True
         except IntegrityError as e:
-            flash(unicode(self.edit_integrity_error_message), 'warning')
-            log.warning("Edit record integrity error")
+            flash(as_unicode(self.edit_integrity_error_message), 'warning')
+            log.warning("Edit record integrity error: {0}".format(str(e)))
             self.session.rollback()
             return False
-        except:
-            flash(unicode(self.general_error_message + ' ' + str(sys.exc_info()[0])), 'danger')
-            log.exception("Edit record error")
+        except Exception as e:
+            flash(as_unicode(self.general_error_message + ' ' + str(sys.exc_info()[0])), 'danger')
+            log.exception("Edit record error: {0}".format(str(e)))
             self.session.rollback()
             return False
 
@@ -294,16 +301,16 @@ class SQLAModel(DataModel):
             self._delete_files(item)
             self.session.delete(item)
             self.session.commit()
-            flash(unicode(self.delete_row_message), 'success')
+            flash(as_unicode(self.delete_row_message), 'success')
             return True
         except IntegrityError as e:
-            flash(unicode(self.delete_integrity_error_message), 'warning')
-            log.warning("Delete record integrity error")
+            flash(as_unicode(self.delete_integrity_error_message), 'warning')
+            log.warning("Delete record integrity error: {0}".format(str(e)))
             self.session.rollback()
             return False
-        except:
-            flash(unicode(self.general_error_message + ' ' + str(sys.exc_info()[0])), 'danger')
-            log.exception("Delete record error")
+        except Exception as e:
+            flash(as_unicode(self.general_error_message + ' ' + str(sys.exc_info()[0])), 'danger')
+            log.exception("Delete record error: {0}".format(str(e)))
             self.session.rollback()
             return False
 
@@ -384,8 +391,8 @@ class SQLAModel(DataModel):
         ret_lst = []
         for prop in self.get_properties_iterator():
             if not self.is_relation(prop):
-                if (not self.is_pk(self.get_property_first_col(prop))) and (
-                        not self.is_fk(self.get_property_first_col(prop))):
+                tmp_prop = self.get_property_first_col(prop)
+                if (not self.is_pk(tmp_prop)) and (not self.is_fk(tmp_prop)):
                     ret_lst.append(prop.key)
             else:
                 ret_lst.append(prop.key)
@@ -399,7 +406,7 @@ class SQLAModel(DataModel):
                 tmp_prop = self.get_property_first_col(prop)
                 if (not self.is_pk(tmp_prop)) and (not self.is_fk(tmp_prop)):
                     col = prop.key
-                    if (not self.is_image(col)) and (not self.is_file(col)):
+                    if (not self.is_image(col)) and (not self.is_file(col)) and (not self.is_boolean(col)):
                         ret_lst.append(col)
             else:
                 ret_lst.append(prop.key)
